@@ -15,8 +15,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <config.h>
-#include <deborphan.h>
+#include "config.h"
+#include "deborphan.h"
 
 /* These files should already be installed on the host machine -
    the GPL does not allow redistribution in this package. */
