@@ -7,14 +7,14 @@
    file COPYING provided in this package for details.
 */
 
+#include <errno.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include <config.h>
-#include <deborphan.h>
-#include <errno.h>
+#include "config.h"
+#include "deborphan.h"
 
 #ifdef ENABLE_NLS
 #include <libintl.h>
